CamToNes
========

CamToNes (Camera To Not Empty Sequece) is a small script to process security
camera video (recorded or streams) to easy extract motion and faces.

Documentation
-------------

You can find the full documentation of the project
`here <http://jespino.github.io/camtones/latest/>`_.

Screenshots
-----------

.. figure:: https://jespino.github.io/camtones/latest/assets/motion-detection.gif
   :scale: 50 %
   :alt: Motion detection

   Motion detection

.. figure:: https://jespino.github.io/camtones/latest/assets/face-detection.gif
   :scale: 50 %
   :alt: Face detection

   Face detection
